==> calligra_2.8.1-1.orig.tar.xz: calligra-2.8.1/krita/ui/kis_workspace_resource.h <==
/* This file is part of the KDE project
 * Copyright (C) 2011 Sven Langkamp <sven.langkamp@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef KIS_WORKSPACE_RESOURCE_H
#define KIS_WORKSPACE_RESOURCE_H

#include <KoResource.h>
#include <kis_properties_configuration.h>

/// Resource for storing of workspaces
class KisWorkspaceResource : public KoResource , public KisPropertiesConfiguration
{

public:
    KisWorkspaceResource(const QString& filename);
    virtual ~KisWorkspaceResource();
    virtual bool save();
    virtual bool load();
    virtual QString defaultFileExtension() const;

    void setDockerState(const QByteArray& state);
    QByteArray dockerState();
    
private:
    QByteArray m_dockerState;
};

#endif // KIS_WORKSPACE_RESOURCE_H

==> calligra_2.9.2.orig.tar.xz: calligra-2.9.2/krita/ui/kis_workspace_resource.h <==
/* This file is part of the KDE project
 * Copyright (C) 2011 Sven Langkamp <sven.langkamp@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef KIS_WORKSPACE_RESOURCE_H
#define KIS_WORKSPACE_RESOURCE_H

#include <KoResource.h>
#include <kis_properties_configuration.h>
#include "krita_export.h"

/// Resource for storing of workspaces
class KRITAUI_EXPORT KisWorkspaceResource : public KoResource , public KisPropertiesConfiguration
{

public:
    KisWorkspaceResource(const QString& filename);
    virtual ~KisWorkspaceResource();
    virtual bool load();
    virtual bool loadFromDevice(QIODevice *dev);
    virtual bool save();
    virtual bool saveToDevice(QIODevice* dev) const;
    virtual QString defaultFileExtension() const;

    void setDockerState(const QByteArray& state);
    QByteArray dockerState();

protected:

    virtual QByteArray generateMD5() const;

private:
    QByteArray m_dockerState;
};

#endif // KIS_WORKSPACE_RESOURCE_H
